@@ -106,7 +106,7 @@ class RestfulModel(dict):
 
         return obj
 
-    def as_json(self):
+    def as_json(self, enforce_read_only=True):
         dct = {}
         # Some API parameters like "from" and "in" also are
         # Python reserved keywords. To work around this, we rename
@@ -114,7 +114,7 @@ class RestfulModel(dict):
         # their correct form though.
         reserved_keywords = ["from", "in"]
         for attr in self.cls.attrs:
-            if attr in self.read_only_attrs:
+            if attr in self.read_only_attrs and enforce_read_only is True:
                 continue
             if hasattr(self, attr):
                 if attr in reserved_keywords:
@@ -124,17 +124,17 @@ class RestfulModel(dict):
                 if attr_value is not None:
                     dct[attr] = attr_value
         for date_attr, iso_attr in self.cls.date_attrs.items():
-            if date_attr in self.read_only_attrs:
+            if date_attr in self.read_only_attrs and enforce_read_only is True:
                 continue
             if self.get(date_attr):
                 dct[iso_attr] = self[date_attr].strftime("%Y-%m-%d")
         for dt_attr, ts_attr in self.cls.datetime_attrs.items():
-            if dt_attr in self.read_only_attrs:
+            if dt_attr in self.read_only_attrs and enforce_read_only is True:
                 continue
             if self.get(dt_attr):
                 dct[ts_attr] = timestamp_from_dt(self[dt_attr])
         for attr, value_attr in self.cls.typed_dict_attrs.items():
-            if attr in self.read_only_attrs:
+            if attr in self.read_only_attrs and enforce_read_only is True:
                 continue
             typed_dict = getattr(self, attr)
             if value_attr:
@@ -151,6 +151,8 @@ class RestfulModel(dict):
 
 
 class NylasAPIObject(RestfulModel):
+    read_only_attrs = {"id", "account_id", "object", "job_status_id"}
+
     def __init__(self, cls, api):
         RestfulModel.__init__(self, cls, api)
 
@@ -638,6 +640,7 @@ class Calendar(NylasAPIObject):
 
     def __init__(self, api):
         NylasAPIObject.__init__(self, Calendar, api)
+        self.read_only_attrs.update({"is_primary", "read_only"})
 
     @property
     def events(self):
@@ -668,12 +671,25 @@ class Event(NylasAPIObject):
         "ical_uid",
         "metadata",
         "notifications",
+        "event_collection_id",
+        "capacity",
+        "round_robin_order",
     ]
     datetime_attrs = {"original_start_at": "original_start_time"}
     collection_name = "events"
 
     def __init__(self, api):
         NylasAPIObject.__init__(self, Event, api)
+        self.read_only_attrs.update(
+            {
+                "ical_uid",
+                "message_id",
+                "owner",
+                "status",
+                "master_event_id",
+                "original_start_time",
+            }
+        )
 
     def as_json(self):
         dct = NylasAPIObject.as_json(self)
@@ -759,7 +775,7 @@ class Event(NylasAPIObject):
             "Unexpected response from the API server. Returned 200 but no 'ics' string found."
         )
 
-    def save(self, **kwargs):
+    def validate(self):
         if (
             self.conferencing
             and "details" in self.conferencing
@@ -768,6 +784,18 @@ class Event(NylasAPIObject):
             raise ValueError(
                 "Cannot set both 'details' and 'autocreate' in conferencing object."
             )
+        if (
+            self.capacity
+            and self.capacity != -1
+            and self.participants
+            and len(self.participants) > self.capacity
+        ):
+            raise ValueError(
+                "The number of participants in the event exceeds the set capacity."
+            )
+
+    def save(self, **kwargs):
+        self.validate()
 
         super(Event, self).save(**kwargs)
 
@@ -804,6 +832,13 @@ class JobStatus(NylasAPIObject):
 
     def __init__(self, api):
         NylasAPIObject.__init__(self, JobStatus, api)
+        self.read_only_attrs.update(
+            {
+                "action",
+                "status",
+                "original_data",
+            }
+        )
 
     def is_successful(self):
         return self.status == "successful"
@@ -871,13 +906,19 @@ class Component(NylasAPIObject):
         "created_at": "created_at",
         "updated_at": "updated_at",
     }
-    read_only_attrs = {"id", "public_application_id", "created_at", "updated_at"}
 
     collection_name = None
     api_root = "component"
 
     def __init__(self, api):
         NylasAPIObject.__init__(self, Component, api)
+        self.read_only_attrs.update(
+            {
+                "public_application_id",
+                "created_at",
+                "updated_at",
+            }
+        )
 
     def as_json(self):
         dct = NylasAPIObject.as_json(self)
@@ -896,13 +937,13 @@ class Webhook(NylasAPIObject):
         "application_id",
         "version",
     )
-    read_only_attrs = {"id", "application_id", "version"}
 
     collection_name = "webhooks"
     api_root = "a"
 
     def __init__(self, api):
         NylasAPIObject.__init__(self, Webhook, api)
+        self.read_only_attrs.update({"application_id", "version"})
 
     def as_json(self):
         dct = {}
