@@ -2,7 +2,6 @@ import json
 from datetime import datetime, timedelta
 import pytest
 from urlobject import URLObject
-from requests import RequestException
 from nylas.client.restful_models import Event
 
 
@@ -15,15 +14,39 @@ def blank_event(api_client):
 
 
 @pytest.mark.usefixtures("mock_event_create_response")
-def test_event_crud(api_client):
+def test_event_crud(mocked_responses, api_client):
     event1 = blank_event(api_client)
+    event1.object = "should not send"
+    event1.account_id = "should not send"
+    event1.job_status_id = "should not send"
+    event1.ical_uid = "should not send"
+    event1.message_id = "should not send"
+    event1.owner = "should not send"
+    event1.status = "should not send"
+    event1.master_event_id = "should not send"
+    event1.original_start_time = "should not send"
     event1.save()
+    request = mocked_responses.calls[0].request
+    body = json.loads(request.body)
     assert event1.id == "cv4ei7syx10uvsxbs21ccsezf"
+    assert "title" in body
+    assert "object" not in body
+    assert "account_id" not in body
+    assert "job_status_id" not in body
+    assert "ical_uid" not in body
+    assert "message_id" not in body
+    assert "owner" not in body
+    assert "status" not in body
+    assert "master_event_id" not in body
+    assert "original_start_time" not in body
 
     event1.title = "blah"
     event1.save()
+    request = mocked_responses.calls[1].request
+    body = json.loads(request.body)
     assert event1.title == "loaded from JSON"
     assert event1.get("ignored") is None
+    assert "id" not in body
 
 
 @pytest.mark.usefixtures("mock_event_create_notify_response")
@@ -115,6 +138,51 @@ def test_event_conferencing_details_autocreate_error(mocked_responses, api_clien
     )
 
 
+@pytest.mark.usefixtures("mock_event_create_response")
+def test_event_error_if_participants_more_than_capacity(mocked_responses, api_client):
+    event = blank_event(api_client)
+    event.capacity = 1
+    event.participants = [
+        {"email": "person1@email.com"},
+        {"email": "person2@email.com"},
+    ]
+    with pytest.raises(ValueError) as excinfo:
+        event.save()
+    assert "The number of participants in the event exceeds the set capacity." in str(
+        excinfo
+    )
+
+
+@pytest.mark.usefixtures("mock_event_create_response")
+def test_event_no_error_if_capacity_negative_one(mocked_responses, api_client):
+    event = blank_event(api_client)
+    event.capacity = -1
+    event.participants = [
+        {"email": "person1@email.com"},
+        {"email": "person2@email.com"},
+    ]
+    event.save()
+
+
+@pytest.mark.usefixtures("mock_event_create_response")
+def test_event_no_error_if_participants_less_than_eql_capacity(
+    mocked_responses, api_client
+):
+    event = blank_event(api_client)
+    event.capacity = 2
+    event.participants = [
+        {"email": "person1@email.com"},
+        {"email": "person2@email.com"},
+    ]
+    event.save()
+    event.capacity = 3
+    event.participants = [
+        {"email": "person1@email.com"},
+        {"email": "person2@email.com"},
+    ]
+    event.save()
+
+
 @pytest.mark.usefixtures("mock_calendars", "mock_events")
 def test_calendar_events(api_client):
     calendar = api_client.calendars.first()
